@@ -136,7 +136,8 @@ my %VCS_EXTRACT = (
     # cvs rootdir followed by optional module name:
     cvs     => sub { return shift =~ /^(.+?)(?:\s+(\S*))?$/;},
     darcs   => sub { return @_;},
-    hg      => sub { return @_;},
+    # hg uri followed by optional -b branchname
+    hg      => sub { return shift =~ /^(.+?)(?:\s+-b\s+(\S*))?$/;},
     # git uri followed by optional "[subdir]", "-b branchname" etc.
     git     =>
       sub { return shift =~ /^(.+?)(?:\s+\[(\S*)\])?(?:\s+-b\s+(\S*))?$/;},
@@ -190,6 +191,7 @@ my %VCS_CANONIFY = (
         ) {
             $_[1] = 'vcs-git-uses-invalid-user-uri';
         }
+        $_[0] =~ s{(https?://.*?\.git)(?:\.git)+$}{$1};
         $_[0] =~ s{https?\Q://git.debian.org/\E(?:git/?)?}
                   {https://anonscm.debian.org/git/};
         $_[0] =~ s{https?\Q://anonscm.debian.org/git/git/\E}
@@ -906,14 +908,6 @@ sub run {
                       if ("$d_pkg-doc" eq $pkg
                         && $field =~ /^(?:pre-)?depends$/);
 
-                    # only trigger this for the preferred alternative
-                    tag 'versioned-dependency-satisfied-by-perl',
-                      "$field: $part_d_orig"
-                      if $alternatives[0][-1] eq $part_d_orig
-                      && &$is_dep_field($field)
-                      && perl_core_has_version($d_pkg, $d_version->[0],
-                        $d_version->[1]);
-
                     tag 'package-relation-with-perl-modules', "$field: $d_pkg"
                       # matches "perl-modules" (<= 5.20) as well as
                       # perl-modules-5.xx (>> 5.20)
@@ -1182,14 +1176,6 @@ sub run {
                           # perl-modules-5.xx (>> 5.20)
                           if $d_pkg =~ /^perl-modules/
                           && $proc->pkg_src ne 'perl';
-
-                        # only trigger this for the preferred alternative
-                        tag 'versioned-dependency-satisfied-by-perl',
-                          "$field: $part_d_orig"
-                          if $alternatives[0][-1] eq $part_d_orig
-                          && &$is_dep_field($field)
-                          && perl_core_has_version($d_pkg, $d_version->[0],
-                            $d_version->[1]);
                     }
 
                     my $all_obsolete = 0;
